@@ -12,7 +12,7 @@ package MooX::Options::Descriptive::Usage;
 
 use strict;
 use warnings;
-our $VERSION = '4.002';    # VERSION
+our $VERSION = '4.003';    # VERSION
 use feature 'say';
 use Text::WrapI18N;
 use Term::Size::Any qw/chars/;
@@ -185,6 +185,31 @@ sub option_pod {
     return join( "\n\n", @man );
 }
 
+sub option_short_usage {
+    my ($self) = @_;
+    my %options_data
+        = defined $self->{target} ? $self->{target}->_options_data : ();
+    my $getopt_options = $self->{options};
+
+    my $prog_name = $self->{prog_name}
+        // Getopt::Long::Descriptive::prog_name;
+
+    my @message;
+    for my $opt (@$getopt_options) {
+        my ($format) = $opt->{spec} =~ /(?:\|\w)?(?:=(.*?))?$/x;
+        my $format_doc_str;
+        $format_doc_str = $format_doc{$format} if defined $format;
+        $format_doc_str = 'JSON'
+            if defined $options_data{ $opt->{name} }{json};
+        push @message,
+              "-"
+            . ( length( $opt->{name} ) > 1 ? "-" : "" )
+            . $opt->{name}
+            . ( defined $format_doc_str ? "=" . $format_doc_str : "" );
+    }
+    return join( " ", $prog_name, map {"[ $_ ]"} @message );
+}
+
 sub warn { return CORE::warn shift->text }
 
 sub die {
@@ -214,7 +239,7 @@ MooX::Options::Descriptive::Usage - Usage class
 
 =head1 VERSION
 
-version 4.002
+version 4.003
 
 =head1 DESCRIPTION
 
@@ -262,6 +287,10 @@ Return the help message for your options
 
 Return the usage message in pod format
 
+=head2 option_short_usage
+
+All options message without help
+
 =head2 warn
 
 Warn your options help message
